package main

import "testing"

func TestPlugToProfile(t *testing.T) {
	// Setup the root node / test data
	// Already have parser tests so manually make them instead
	root := &Node{
		Tag:   "root",
		Line:  "testing",
		Depth: -1,
	} // This data is from Test Dummy.txt
	n := root.NewChild()
	n.Set("pilot", "Test Dummy")
	n = root.NewChild()
	n.Set("date", "16 11 3013")
	n = root.NewChild()
	n.Set("system", "Rutilicus")
	n = root.NewChild()
	n.Set("planet", "New Boston")
	n = root.NewChild()
	n.Set("playtime", 19.816336)

	// Begin testing
	var plug Plugin = &Profile{}

	if plug.Type() != "Profile" {
		t.Fail()
		t.Logf("Expected Plugin type of 'Profile', got '%s'", plug.Type())
	}
	err := plug.Parse(root)
	if err != nil {
		t.Errorf("Plugin.Parse, %v", err)
	}
	p := PlugToProfile(plug)
	if p == nil {
		t.Errorf("Unexpected, checked for plugin type of Profile failed conversion")
	}

	// Check the Profile
	if p.Name != "Test Dummy" {
		if !t.Failed() {
			t.Fail()
		}
		t.Logf("Expected Profile.Name 'Test Dummy', got '%s'", p.Name)
	}
	if p.Date != "16 11 3013" {
		if !t.Failed() {
			t.Fail()
		}
		t.Logf("Expected Profile.Date '16 11 3013', got '%s'", p.Date)
	}
	if p.Location.String() != "New Boston, Rutilicus" {
		if !t.Failed() {
			t.Fail()
		}
		t.Logf("Expected Profile.Location 'New Boston, Rutilicus', got '%s'", p.Location.String())
	}
	if p.Location.Type() != "Location" {
		if !t.Failed() {
			t.Fail()
		}
		t.Logf("Expected Location.Type() 'Location', got '%s'", p.Location.Type())
	}
	if p.Playtime != 19.816336 {
		if !t.Failed() {
			t.Fail()
		}
		t.Logf("Expected Profile.Playtime 19.816336, got %f", p.Playtime)
	}
}
