package main

import (
	"fmt"
	"time"
)

type Profile struct {
	Name     string
	Date     string   // for now it's a string (TODO date.go)
	Location Location // System and Plant, also satisfies as a plugin
	Playtime float64  // Play time in seconds
	// TODO travel.go
}

// String representation of Playtime
func (p *Profile) PlayTime() string {
	t := time.Duration(p.Playtime) * time.Second
	return t.String()
}

func (p *Profile) Parse(node *Node) error {
	if node.Tag != "root" {
		return fmt.Errorf("non-root node given, expected root node")
	}
	for _, kid := range node.Children {
		switch kid.Key() {
		case "pilot":
			p.Name = kid.Value()
		case "date":
			p.Date = kid.Value()
		case "system":
			p.Location.Parse(kid)
		case "planet":
			p.Location.Parse(kid)
		case "playtime":
			p.Playtime = kid.ValueFloat64()
		}
	}
	return nil
}

func (p *Profile) Update(node *Node) error {
	if node.Tag != "root" {
		return fmt.Errorf("non-root node given, expected root node")
	}
	err := p.Location.Update(node)
	if err != nil {
		return err
	}
	for _, kid := range node.Children {
		switch kid.Key() {
		case "pilot":
			kid.SetValue(p.Name)
		case "date":
			kid.SetValue(p.Date)
		case "playtime":
			kid.SetValue(p.Playtime)
		}
	}
	return nil
}

func (p *Profile) Type() string {
	return "Profile"
}
